(history)=

# History

More information on how the package was created, who are the people behind it, and its mission.

## Creation

GeoUtils was created during the [GlacioHack](https://github.com/GlacioHack) hackaton event, that took place online on November 8, 2020 and was initiated by
Amaury Dehecq<sup>2</sup>.

```{margin}
<sup>2</sup>More on our GlacioHack founder at [adehecq.github.io](https://adehecq.github.io/)!
```

GeoUtils is inspired by previous efforts that were built directly on top of GDAL and OGR, namely:

- the older, homonymous package [GeoUtils](https://github.com/adehecq/geoutils_old),
- the class [pybob.GeoImg](https://github.com/iamdonovan/pybob/blob/master/pybob/GeoImg.py),
- the package [pygeotools](https://github.com/dshean/pygeotools), and
- the package [salem](https://github.com/fmaussion/salem).

The initial core development of GeoUtils was mainly performed by members of the Glaciology group of the _Laboratory of Hydraulics, Hydrology and
Glaciology (VAW)_ at ETH Zürich<sup>3</sup> and of the _University of Fribourg_, both in Switzerland. The package also received contributions by members of
the _University of Oslo_, Norway, the _University of Washington_, US and _Université Grenobles Alpes_, France.

```{margin}
<sup>3</sup>Check-out [glaciology.ch](https://glaciology.ch) on our founding group of VAW glaciology!
```

## Joining effort with **demcompare**

In 2024, GeoUtils and [demcompare](https://github.com/CNES/demcompare) joined efforts in the perspective of
merging the best of both packages into one, and to jointly continue the development of new features for
analyzing geospatial and in particular elevation data with a larger expertise pool.

[demcompare](https://github.com/CNES/demcompare) is a tool developed by the CNES (French Space Agency) to
support its 3D satellite missions in analyzing elevation data, for instance from stereophotogrammetric DEMs
that can be generated with [CARS](https://github.com/CNES/cars).

## Current team

```{margin}
<sup>3</sup>More on CNES's 3D missions on the [CO3D constellation page](https://cnes.fr/en/projects/co3d).
```

The current lead development team includes **researchers in Earth observation and engineers from
[CNES](https://cnes.fr/en)** (French Space Agency). We specialize in elevation data analysis, for application in Earth
science or for operational use for 3D satellite missions<sup>3</sup>.

Other volunteer contributors span diverse scientific backgrounds in industry or research. We welcome
any new contributors! See how to contribute on [the dedicated page of our repository](https://github.com/GlacioHack/xdem/blob/main/CONTRIBUTING.md).
